You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@streampark.apache.org by mo...@apache.org on 2022/10/31 02:09:43 UTC

[incubator-streampark] 02/02: fix

This is an automated email from the ASF dual-hosted git repository.

monster pushed a commit to branch fs
in repository https://gitbox.apache.org/repos/asf/incubator-streampark.git

commit b3d918bf3e00089e51d34c2c73814419164aa018
Author: Monster <25...@qq.com>
AuthorDate: Mon Oct 31 10:00:51 2022 +0800

    fix
---
 .../org/apache/streampark/common/conf/Workspace.scala | 19 ++++++++++++-------
 1 file changed, 12 insertions(+), 7 deletions(-)

diff --git a/streampark-common/src/main/scala/org/apache/streampark/common/conf/Workspace.scala b/streampark-common/src/main/scala/org/apache/streampark/common/conf/Workspace.scala
index 8206a2c6a..a60c00b28 100644
--- a/streampark-common/src/main/scala/org/apache/streampark/common/conf/Workspace.scala
+++ b/streampark-common/src/main/scala/org/apache/streampark/common/conf/Workspace.scala
@@ -41,22 +41,22 @@ object Workspace {
   /**
    * dirPath of the maven local repository with built-in compilation process
    */
-  lazy val MAVEN_LOCAL_DIR = s"$localWorkspace/mvnrepo"
+  lazy val MAVEN_LOCAL_PATH = s"$localWorkspace/mvnrepo"
 
   /**
    * local sourceCode dir.(for git...)
    */
-  lazy val PROJECT_LOCAL_DIR = s"$localWorkspace/project"
+  lazy val PROJECT_LOCAL_PATH = s"$localWorkspace/project"
 
   /**
    * local log dir.
    */
-  lazy val LOG_LOCAL_DIR = s"$localWorkspace/logs"
+  lazy val LOG_LOCAL_PATH = s"$localWorkspace/logs"
 
   /**
    * project build log dir.
    */
-  lazy val PROJECT_BUILD_LOG_DIR = s"$LOG_LOCAL_DIR/build_logs"
+  lazy val PROJECT_BUILD_LOG_PATH = s"$LOG_LOCAL_PATH/build_logs"
 
 }
 
@@ -125,5 +125,10 @@ case class Workspace(storageType: StorageType) {
    */
   lazy val APP_JARS = s"$WORKSPACE/jars"
 
+  /**
+   * project archives path
+   */
+  lazy val ARCHIVES_FILE_PATH = s"${Workspace.remote.WORKSPACE}/historyserver/archive"
+
 }
@@ -41,22 +41,22 @@ object Workspace {
 
   /**
-   * local sourceCode dir.(for git...)
+   * local sourceCode path.(for git...)
    */
@@ -41,22 +41,22 @@ object Workspace {
 
   /**
-   * local log dir.
+   * local log path.
    */
@@ -41,22 +41,22 @@ object Workspace {
 
   /**
-   * project build log dir.
+   * project build log path.
    */